@@ -49,12 +49,13 @@ class Bootstrap(object):
         app.config.setdefault('BOOTSTRAP_USE_CDN', False)
         app.config.setdefault('BOOTSTRAP_CDN_PREFER_SSL', True)
         app.config.setdefault('BOOTSTRAP_FONTAWESOME', False)
+        app.config.setdefault('BOOTSTRAP_CUSTOM_CSS', False)
         app.config.setdefault(
             'BOOTSTRAP_CDN_BASEURL', {
-                'bootstrap':   '//netdna.bootstrapcdn.com/'\
-                               'twitter-bootstrap/2.3.0/',
-                'fontawesome': '//netdna.bootstrapcdn.com/'\
-                               'font-awesome/3.0/',
+                'bootstrap':   '//cdnjs.cloudflare.com/ajax/libs'
+                               '/twitter-bootstrap/2.3.0/',
+                'fontawesome': '//cdnjs.cloudflare.com/ajax/libs'
+                               '/font-awesome/3.0.2/',
             }
         )
 
